#include "wifi_bglib.h"
#include <string.h>
#include "resources.h"

/** Display alignment parameters */
#define INIT_ROW 50
#define MARGIN  30
#define MAX_LEN 40
#define MAX_TITLE_COUNT 10
#define MAX_TITLE_DISPLAY 2

/** Buffers and variables for text display */
uint8_t row = INIT_ROW;
uint8_t txt[256];
uint8_t h_buffer[MAX_TITLE_COUNT][256];
uint8_t h_tmp[256];
uint8_t h_cur,h_cnt;

/** Display pins initialization */
unsigned int TFT_DataPort at GPIOE_ODR;
sbit TFT_RST at GPIOE_ODR.B8;
sbit TFT_RS at GPIOE_ODR.B12;
sbit TFT_CS at GPIOE_ODR.B15;
sbit TFT_RD at GPIOE_ODR.B10;
sbit TFT_WR at GPIOE_ODR.B11;
sbit TFT_BLED at GPIOE_ODR.B9;


/** Clears the display space for new text*/
void TFT_clear()
{
  row = INIT_ROW;
  TFT_Fill_Screen( CL_WHITE );
  TFT_Line( 20,  40, 300,  40 );
  TFT_Line( 20, 220, 300, 220 );
  TFT_Set_Font( &HandelGothic_BT21x22_Regular , CL_RED, FO_HORIZONTAL );
  TFT_Write_Text( "WiFi 6 click", 100, 14 );
  TFT_Set_Font( &Verdana12x13_Regular, CL_BLACK, FO_HORIZONTAL );
  TFT_Write_Text("EasyMx PRO v7 for STM32", 19, 223);
  TFT_Set_Font( &Verdana12x13_Regular, CL_RED, FO_HORIZONTAL );
  TFT_Write_Text( "www.mikroe.com", 200, 223 );
  TFT_Set_Font( TFT_defaultFont, CL_BLACK, FO_HORIZONTAL );
}

/** TFT initialization */
void init_TFT()
{
   TFT_Init_ILI9341_8bit(320, 240);
   TFT_BLED = 1;
   TFT_Set_Pen( CL_WHITE, 1 );
   TFT_Set_Brush( 1,CL_WHITE,0,0,0,0 );
   TFT_Set_Font( TFT_defaultFont, CL_BLACK, FO_HORIZONTAL );
   TFT_Set_Pen( CL_BLACK, 1 );
   TFT_clear();
}

/** Displays a text message in a new row */
uint8_t TFT_display_message(uint8_t* text)
{
   char *end;
   if(strlen(text)>MAX_LEN)
   {
       return -1;
   }
   if(row>=230)
   {
      delay_ms(50);
      TFT_clear();
   }
   
   TFT_write_text(text,MARGIN,row);
   row+=20;
   
   return 0;
}

/** Displays device status */
void show_status(uint8_t* text, uint8_t uart_only)
{
   UART1_Write_Text(text);
   if(text[strlen(text)-1] == ':')
       UART1_Write_Text(" ");
   else
       UART1_Write_Text("\r\n");
   if(!uart_only)
      TFT_display_message(text);
}

/** Displays data in hexadecimal format */
void show_status_hex(uint32_t buffer, uint8_t displ_mode)
{
   /*
      Mode is used for customizing the output,
      each bit in displ_mode argument is used to select
      specific options:
      
      bit0 - message is displayed on TFT
      bit2 - message is displayed on UART
      
      Also, if displ_mode is greater than 1
      data is displayed in three formats.
   */
   if(displ_mode>1)
   {
      sprintf(txt,"0x%LX %Ld '%c'",buffer,buffer,buffer);
   }
   else
   {
      sprintf(txt,"0x%LX",buffer);
   }
   UART1_Write_Text(txt);
   if(!(displ_mode & 0x4))
      UART1_Write_Text("\r\n");
   if(!(displ_mode & 0x1))
      TFT_display_message(txt);
}

/** Displays data in decimal format */
void show_status_dec(uint32_t buffer, uint8_t uart_only)
{
   sprintf(txt,"%u",buffer);
   UART1_Write_Text(txt);
   UART1_Write_Text("\r\n");
   if(!uart_only)
      TFT_display_message(txt);
}

/** Displays data in IP address format */
void show_status_IP(uint8_t* a, uint8_t uart_only)
{
    sprintf(txt,"%d.%d.%d.%d",a[0],a[1],a[2],a[3]);
    show_status(txt,uart_only);
}

/** Displays data in IP address format from a given uint32 */
void show_status_IP_uint(uint32_t addr, uint8_t uart_only)
{
    uint8_t a[4],i;
    for(i=0;i<4;i++)
    {
        a[i] = addr & 0xFF;
        addr >>= 8;
    }
    sprintf(txt,"%d.%d.%d.%d",a[0],a[1],a[2],a[3]);
    show_status(txt,uart_only);
}

/** Displays a news headline */
void show_headline(uint8_t* h_data)
{
     /*
        Word wrap is implemented to adapt the
        string for TFT output.
     */

     uint16 h_len = strlen(h_data);
     uint16 start=0,cur=0,space_cur=0;
     if(TFT_display_message(h_data)==0)
     {
         return;
     }

     while(h_data[cur])
     {
        while(cur<=MAX_LEN)
        {
           if(h_data[cur]==' ')
           {
               space_cur = cur;
           }
           if(h_data[cur]=='\0')
           {
              memcpy(h_tmp,h_data,cur);
              h_tmp[cur] = '\0';
              TFT_display_message(h_tmp);
              return;
           }
           cur++;
        }
        memcpy(h_tmp,h_data,space_cur);
        h_tmp[space_cur] = '\0';
        TFT_display_message(h_tmp);
        h_data += space_cur;
        cur = 0;
    }
}

/** Displays headlines from RSS news feed */
void show_data_xml(uint8_t* data)
{
     /*
        Headlines are extracted from the dowloaded XML,
        then displayed on TFT.
     */
     
     uint8_t i,buffer_cur = 0;
     h_cnt = 0;
     show_status("\r\n\r\n",1);
     while(*data && h_cnt < MAX_TITLE_COUNT)
     {
        if(*data=='<')
        {
           if(!strncmp(data,"<title>",7))
           {
               data+=7;
               while(*data != '<')
               {
                  txt[buffer_cur++] = *data;
                  data++;
               }
               txt[buffer_cur] = '\0';
               show_status(txt,1);
               memcpy(h_buffer[h_cnt],txt,buffer_cur);
               buffer_cur = 1;
               txt[0] = '-';
               h_cnt++;
           }
        }
        data++;
     }
     
     h_cur=2;
     while(1)
     {
        TFT_clear();
        TFT_display_message(h_buffer[0]);
        TFT_display_message("");
        for(i=0;i<MAX_TITLE_DISPLAY;i++)
        {
          show_headline(h_buffer[h_cur]);
          h_cur = 2 + (h_cur+1) % (h_cnt-2);
          TFT_display_message("");
        }
        delay_ms(10000);
     }
}