#include <stdlib.h>
#include <stddef.h>
#include "wifi_bglib.h"
#include "uart.h"
#include "display.h"

/*
   WiFi 6 Example
   
   The example demonstrates a simple use of WiFi 6 click, which downloads
   an RSS feed in folowing steps:
   
   -Module initialization
   -Connection to a predefined access point
   -Resolving a hostname IP address using DNS servers
   -Creating a TCP connection
   -Sending a HTTP request
   -Downloading data from HTTP response
   -Extracting and displaying downloaded data
   
   This program represents a modified version of the example from BlueGiga SDK.
   
   WF121 module works using a simple command and response protocol called BGAPI,
   all the communication is achieved using the UART module.
   
   Plug the click into mikroBUS1 socket and run the example.
   To use mikroBUS2 socket, follow the instructions from uart.c file.
   
   For additional information on how the example works, connect USB UART A
   to the terminal.

*/

/** RTS/CTS handshake signal pins*/
extern sfr sbit MCU_RTS;
extern sfr sbit MCU_CTS;

/** BGLib definitions */
BGLIB_DEFINE

/** Module states enumeration */
enum wlan_state
{
    /** Send Hello command. */
    wlan_state_hello,
    /** Reset the module. */
    wlan_state_reset,
    /** Switch Wi-Fi on. */
    wlan_state_wifi_on,
    /** Do a scan for available Wi-Fi networks. */
    wlan_state_connect,
    /** Open a TCP connection. */
    wlan_state_tcp_connect,
    /** Send an HTTP GET request. */
    wlan_state_tcp_send,
    /** Disconnect from the Wi-Fi access point. */
    wlan_state_disconnect,
    /** Send a DNS resolve request. */
    wlan_state_dns_resolve,
    /** Max power save mode */
    wlan_state_max_power,
    /** Set AP password */
    wlan_state_set_pass
    
};

/** Current state of the system. */
enum wlan_state internal_state;
/** TCP endpoint. */
uint8_t tcp_endpoint;
/** Buffer for received data. */
uint8_t recv_buffer[32768];
/** Index to receive buffer. */
uint32_t recv_buffer_idx = 0;
/** The destination IP address */
uint32_t dest_ip = 0;
/** Resolved host IP */
uint8_t host_ip[4];
/** Variable for storing function return values.*/
int ret;
/** Pointer to wifi packet*/
struct wifi_cmd_packet* pck;
/** Buffer for storing data from the serial port.*/
uint8_t buffer[BGLIB_MSG_MAXLEN];
/** Length of message payload data.*/
uint16_t msg_length;
/** Device IP*/
ipv4 device_ip;



/******************************************************************************
                            Example parameters
*******************************************************************************/

/** AP parameters */
const uint8* ssid_data = "TP Link";
const uint8* password_data = "123456789";



/** TCP connection parameters */
char* host = "feeds.reuters.com";
char HTTP_req[] = "GET /reuters/scienceNews?format=xml HTTP/1.1\r\nHost: feeds.reuters.com\r\nConnection: close\r\n\r\n";
uint16_t dest_port = 80;

/*******************************************************************************/


/** Macro for ending the program */
#define MCU_END\
{\
  MCU_RTS =1;\
  while(1);\
}


/** Adapted reset command */
void wifi_cmd_system_reset_STM32(uint8 dfu)
{
     /** The module sends 0x00 when reset.*/
     uint8 tmp;
     wifi_cmd_system_reset(dfu);
     uart_get(1,&tmp);
}


/** BGAPI output function */
void uart_output(uint8_t len1,uint8_t* data1,uint16_t len2,uint8_t* data2)
{
        uint8_t temp;
        temp = uart_send(len1, data1);
        
        if (temp < 0) 
           show_status("UART output failed",1);

        if (len2 > 0)
        {
          if ( data2 )
            {
                temp = uart_send(len2,data2);
                if (temp < 0) 
                   show_status("UART output failed",1);
            }
        }
}


/** Switch states */
void goto_state(enum wlan_state state)
{
    switch(state)
    {
        case wlan_state_hello:
            show_status("Checking UART connection...",1);
            wifi_cmd_system_hello();
            break;
        case wlan_state_reset:
            show_status("Initializing module...",0);
            wifi_cmd_system_reset_STM32(0);
            break;
        case wlan_state_wifi_on:
            show_status("Turning WiFi radio on...",1);
            wifi_cmd_sme_wifi_on();
            break;
        case wlan_state_connect:
            show_status("Connecting...",0);
            wifi_cmd_sme_connect_ssid(strlen(ssid_data),ssid_data);
            break;
        case wlan_state_tcp_connect:
             show_status("Initiating TCP connection...",1);
             wifi_cmd_tcpip_tcp_connect(dest_ip, dest_port, -1);
            break;
        case wlan_state_tcp_send:
            show_status("Sending HTTP request...",1);
            wifi_cmd_endpoint_send(tcp_endpoint, strlen(HTTP_req), HTTP_req);
            break;
        case wlan_state_disconnect:
            show_status("Disconnecting...",1);
            wifi_cmd_sme_disconnect();
            break;
        case wlan_state_dns_resolve:
            show_status("Sending a DNS request...",1);
            wifi_cmd_tcpip_dns_gethostbyname(strlen(host),host);
            break;
        case wlan_state_max_power:
            show_status("Turning power saver off...",1);
            wifi_cmd_system_set_max_power_saving_state(0);
            break;
        case wlan_state_set_pass:
            show_status("Setting password for AP...",1);
            wifi_cmd_sme_set_password(strlen(password_data),password_data);
            break;
            
        default:
            break;
    }
    internal_state = state;
}


void main ()
{

    //TFT display output initialization.
    init_TFT();
    
    //USB UART initialization.
    UART1_Init(115200);
    show_status("\r\n**************************",1);
    show_status("UART1 initialized",1);

    //WF121 UART initialization.
    init_WF121_UART();
    
    //Initialize BGLIB with our output function for sending messages.
    BGLIB_INITIALIZE(uart_output);
    
    //Send a Hello command to verify the serial port is working.
    goto_state(wlan_state_hello);
    
    while(1)
    {

        //Clear the message buffer.
        memset(buffer,0,BGLIB_MSG_MAXLEN);


        //Read enough data from serial port for the BGAPI message header.
        ret = uart_get(BGLIB_MSG_HEADER_LEN, buffer);
        if(ret < 0)
        {
            show_status("main() - failed to read from serial port!",1);
            MCU_END
        }

        //The buffer now contains the message header.
        msg_length = BGLIB_MSG_LEN(buffer);

        //Read the payload data if required and store it after the header.
        if(msg_length)
        {
            ret = uart_get(msg_length, &buffer[BGLIB_MSG_HEADER_LEN]);
            if(ret < 0)
            {
                show_status("main() - failed to read from serial port!",1);
                MCU_END
            }
        }

        //Convert UART input into a structure
        pck=BGLIB_MSG(buffer);
        
        //Detect message type
        switch(BGLIB_MSG_ID(buffer))
        {
            
            case wifi_rsp_system_hello_id:
            
                TFT_clear();
                show_status("UART connected",1);
                
                /*
                   UART works, reset the module.
                */
                goto_state(wlan_state_reset);
                break;
                
            case wifi_evt_system_boot_id:
            
                show_status("Boot successfull.",1);
                show_status("Major version:",1);
                show_status_dec(pck->evt_system_boot.major,1);
                show_status("Minor version:",1);
                show_status_dec(pck->evt_system_boot.minor,1);
                show_status("Patch version:",1);
                show_status_dec(pck->evt_system_boot.patch,1);
                show_status("Build:",1);
                show_status_dec(pck->evt_system_boot.build,1);
                
                /*
                   Boot complete, disable power saver 
                   for better performance.
                */
                goto_state(wlan_state_max_power);
                break;
                
            case wifi_rsp_system_set_max_power_saving_state_id:
            
                 if(pck->rsp_system_set_max_power_saving_state.result==0)
                 {
                    show_status("Power saver off.",1);
                 }
                 else
                 {
                    show_status("Power saver command error!",1);
                 }
                 
                 /*
                    Power saver off. Turn on the WiFi radio.
                 */
                 goto_state(wlan_state_wifi_on);
                 break;

            case wifi_rsp_sme_wifi_on_id:

                show_status("on_wifi_rsp_sme_wifi_on",1);

                if(pck->rsp_sme_wifi_on.result != wifi_err_success)
                {
                    show_status("Wi-Fi On command failed!",1);
                    MCU_END
                }
                break;

            case wifi_evt_sme_wifi_is_on_id:
            
                show_status("WiFi is on.",1);

                if(pck->evt_sme_wifi_is_on.result != wifi_err_success)
                {
                    show_status("Unable to switch Wi-Fi on!",0);
                    MCU_END
                }

                /*
                   WiFi radio is on, set the AP password.
                */
                goto_state(wlan_state_set_pass);
                break;

            case wifi_rsp_sme_set_password_id:

                 show_status("wifi_rsp_sme_set_password",1);
                 
                 if(pck->rsp_sme_set_password.status != wifi_err_success)
                 {
                     show_status("Password change failed!",0);
                     MCU_END
                 }
                 
                 /*
                    Password is set, connect to the AP.
                 */
                 goto_state(wlan_state_connect);
                 break;


            case wifi_evt_sme_connected_id:
            
                show_status("wifi_evt_sme_connected_id",1);
                
                show_status("AP connected:",1);
                show_status(ssid_data,1);
                show_status("Obtaining IP configuration...",0);
                
                if(pck->evt_sme_connected.status)
                {
                    show_status("Wi-Fi connection failed!",0);
                    MCU_END
                }
                
                /*
                   Wi-Fi connection has been established, waiting for an Interface Status event
                   to indicate an IP has been configured.
                */
                break;


            case wifi_evt_tcpip_configuration_id:

                device_ip = pck->evt_tcpip_configuration.address;
                show_status("Connected.",1);
                show_status("Device IP:",1);
                show_status_IP(device_ip.a,1);
                show_status("Default gateway:",1);
                show_status_IP(pck->evt_tcpip_configuration.gateway.a,1);
                
                /*
                    IP configuration obtained.
                    Waiting for interface status event.
                */
                break;

            case wifi_evt_sme_interface_status_id:
            
                show_status("on_wifi_evt_sme_interface_status",1);

                if(pck->evt_sme_interface_status.status)
                {
                     /*
                       Network is up. Resolve hostname IP using DNS.
                     */
                    goto_state(wlan_state_dns_resolve);
                }
                break;

            case wifi_rsp_tcpip_dns_gethostbyname_id:
            
                    show_status("wifi_rsp_tcpip_dns_gethostbyname",1);
                    show_status("Result:",1);
                    show_status_hex(pck->rsp_tcpip_dns_gethostbyname.result,1);
                break;
                
            case wifi_evt_tcpip_dns_gethostbyname_result_id:

                     show_status("wifi_evt_tcpip_dns_gethostbyname_result",1);
                     show_status("Result:",1);
                     show_status_hex(pck->evt_tcpip_dns_gethostbyname_result.result,1);
                     dest_ip =  pck->evt_tcpip_dns_gethostbyname_result.address.u;
                     show_status("DNS resolved:",1);
                     show_status(pck->evt_tcpip_dns_gethostbyname_result.name.data,1);
                     show_status("Host IP address:",1);
                     show_status_IP(pck->evt_tcpip_dns_gethostbyname_result.address.a,1);
                     
                     /*
                        DNS resolved, initiate TCP connection with the
                        remote server.
                     */
                     goto_state(wlan_state_tcp_connect);
                break;
                
            case wifi_evt_tcpip_endpoint_status_id:

                show_status("wifi_evt_tcpip_endpoint_status\n",1);
                show_status("Endpoint:",1);
                show_status_dec(pck->evt_tcpip_endpoint_status.endpoint,1);
                show_status("Local IP:",1);
                show_status_IP(pck->evt_tcpip_endpoint_status.local_ip.a,1);
                show_status("Local port:",1);
                show_status_dec(pck->evt_tcpip_endpoint_status.local_port,1);
                show_status("Remote IP:",1);
                show_status_IP(pck->evt_tcpip_endpoint_status.remote_ip.a,1);
                show_status("Remote port:",1);
                show_status_dec(pck->evt_tcpip_endpoint_status.remote_port,1);

                /*
                   TCP endpoint created.
                */
                break;

                
            case wifi_rsp_tcpip_tcp_connect_id:
                
                show_status("TCP connection established.",1);
                show_status("wifi_rsp_tcpip_tcp_connect",1);
                show_status("Result:",1);
                show_status_dec(pck->rsp_tcpip_tcp_connect.result,1);
                
                /*
                  TCP connection created. Get the ID of the endpoint.
                */
                if(pck->rsp_tcpip_tcp_connect.result != 0)
                {
                    show_status("TCP connection failed",0);
                    MCU_END
                }

                tcp_endpoint = pck->rsp_tcpip_tcp_connect.endpoint;
                show_status("TCP endpoint ID:",1);
                show_status_dec(tcp_endpoint,1);

                 /*
                   Waiting for an endpoint status event that indicates 
                   the endpoint is now active until sending the HTTP GET request.
                 */
                break;

                
            case wifi_evt_endpoint_status_id:
                
                show_status("wifi_evt_endpoint_status",1);
                show_status("Endpoint:",1);
                show_status_dec(pck->evt_endpoint_status.endpoint,1);
                show_status("Type:",1);
                show_status_dec(pck->evt_endpoint_status.type,1);
                show_status("Streaming:",1);
                show_status_dec(pck->evt_endpoint_status.streaming,1);
                show_status("Destination:",1);
                show_status_dec(pck->evt_endpoint_status.destination,1);
                show_status("Active:",1);
                show_status_dec(pck->evt_endpoint_status.active,1);
                
                /*
                   If this is the endpoint assigned to the TCP connection opened earlier and it's active, send the HTTP GET request.
                */
                if(pck->evt_endpoint_status.endpoint == tcp_endpoint && pck->evt_endpoint_status.active && internal_state == wlan_state_tcp_connect)
                {
                    goto_state(wlan_state_tcp_send);
                }
                break;
            

                
             case wifi_rsp_endpoint_send_id:

                show_status("Request sent!",1);
                show_status("Downloading data...",0);
                if(pck->rsp_endpoint_send.endpoint == tcp_endpoint && internal_state == wlan_state_tcp_send && pck->rsp_endpoint_send.result != wifi_err_success)
                {
                    show_status("Endpoint send failed!",1);
                }
                
                /*
                   HTTP request sent, waiting for response.
                */
                break;

            case wifi_evt_endpoint_data_id:

                /*
                   Instead of parsing the data as it's received, it's simply copied to a big buffer
                   and handled when the server closes the connection.
                */
                memcpy(recv_buffer+recv_buffer_idx, pck->evt_endpoint_data.data.data, pck->evt_endpoint_data.data.len);
                recv_buffer_idx += pck->evt_endpoint_data.data.len;
                break;
                
                
            case wifi_evt_endpoint_closing_id:

                show_status("Data downloaded.",1);
                show_status("wifi_evt_endpoint_closing",1);
                if(internal_state == wlan_state_tcp_send)
                {
                    recv_buffer[recv_buffer_idx] = '\0';
                    goto_state(wlan_state_disconnect);
                    /*
                       Endpoint closing. Data download is complete, and WiFi can
                       now disconnect.
                    */
                }
                else
                {
                    /*
                       TCP connection was closed unexpectedly.
                    */
                    show_status("TCP connection closed unexpectedly!",0);
                    show_status("Endpoint:",1);
                    show_status_dec(pck->evt_endpoint_closing.endpoint,1);
                    show_status("Reason:",1);
                    show_status_hex(pck->evt_endpoint_closing.reason,1);
                    MCU_END
                }
                break;
                

                
            case wifi_evt_system_power_saving_state_id:
            
                 if(pck->evt_system_power_saving_state.state == 1)
                     show_status("Power save mode enabled",1);
                 else
                     show_status("Power save mode disabled",1);
                break;


            case wifi_rsp_sme_disconnect_id:
            
                show_status("on_wifi_rsp_sme_disconnect",1);

                if(pck->rsp_sme_disconnect.result != wifi_err_success)
                {
                    show_status("Wi-Fi disconnect failed",1);
                    MCU_END
                }
                break;
                
            case wifi_evt_sme_disconnected_id:
            
                show_status("on_wifi_evt_sme_disconnected:",1);
                if(internal_state == wlan_state_disconnect)
                {
                    /*
                       All done, disconnect.
                    */
                    show_status("Wi-Fi disconnected.",1);
                    show_data_xml(recv_buffer);
                    MCU_END
                } else
                {
                    /*
                       An unexpected disconnection from the access point.
                    */
                    show_status("Unexpected Wi-Fi disconnect!",0);
                    show_status_hex(pck->evt_sme_disconnected.reason,1);
                    MCU_END
                }
                break;
                
            case wifi_evt_sme_connect_failed_id:

                /*
                   WiFi connection failed.
                */
                show_status("on_wifi_evt_sme_connect_failed:",1);
                show_status_hex(pck->evt_sme_connect_failed.reason,1);
                if(pck->evt_sme_connect_failed.reason != wifi_err_success)
                {
                    show_status("Wi-Fi connection failed",0);
                    MCU_END
                }
                break;

            default:
                break;

        }
        }
}